@@ -1,10 +1,12 @@
 import os
 import sys
 import gettext
+import pygtk
+pygtk.require('2.0')
 
 from sqlkit.misc import utils
 
-__version__ = '0.9.1'
+__version__ = '0.9.2'
 
 
 cwd = os.path.abspath(os.path.dirname(__file__))
